---
title: llarp/rpc/rpc_command_definitions.hpp

---

# llarp/rpc/rpc_command_definitions.hpp



## Namespaces

| Name           |
| -------------- |
| **[llarp](Namespaces/namespacellarp.md)** <br>[crypto.hpp] |
| **[llarp::rpc](Namespaces/namespacellarp_1_1rpc.md)**  |

## Classes

|                | Name           |
| -------------- | -------------- |
| struct | **[llarp::rpc::LOGS](Classes/structllarp_1_1rpc_1_1LOGS.md)**  |
| struct | **[llarp::rpc::HALT](Classes/structllarp_1_1rpc_1_1HALT.md)**  |
| struct | **[llarp::rpc::VERSION](Classes/structllarp_1_1rpc_1_1VERSION.md)**  |
| struct | **[llarp::rpc::STATUS](Classes/structllarp_1_1rpc_1_1STATUS.md)**  |
| struct | **[llarp::rpc::GETSTATUS](Classes/structllarp_1_1rpc_1_1GETSTATUS.md)**  |
| struct | **[llarp::rpc::QUICCONNECT](Classes/structllarp_1_1rpc_1_1QUICCONNECT.md)**  |
| struct | **[llarp::rpc::QUICCONNECT::request_parameters](Classes/structllarp_1_1rpc_1_1QUICCONNECT_1_1request__parameters.md)**  |
| struct | **[llarp::rpc::QUICLISTENER](Classes/structllarp_1_1rpc_1_1QUICLISTENER.md)**  |
| struct | **[llarp::rpc::QUICLISTENER::request_parameters](Classes/structllarp_1_1rpc_1_1QUICLISTENER_1_1request__parameters.md)**  |
| struct | **[llarp::rpc::LOOKUPSNODE](Classes/structllarp_1_1rpc_1_1LOOKUPSNODE.md)**  |
| struct | **[llarp::rpc::LOOKUPSNODE::request_parameters](Classes/structllarp_1_1rpc_1_1LOOKUPSNODE_1_1request__parameters.md)**  |
| struct | **[llarp::rpc::ENDPOINT](Classes/structllarp_1_1rpc_1_1ENDPOINT.md)**  |
| struct | **[llarp::rpc::ENDPOINT::request_parameters](Classes/structllarp_1_1rpc_1_1ENDPOINT_1_1request__parameters.md)**  |
| struct | **[llarp::rpc::EXIT](Classes/structllarp_1_1rpc_1_1EXIT.md)**  |
| struct | **[llarp::rpc::EXIT::request_parameters](Classes/structllarp_1_1rpc_1_1EXIT_1_1request__parameters.md)**  |
| struct | **[llarp::rpc::DNSQUERY](Classes/structllarp_1_1rpc_1_1DNSQUERY.md)**  |
| struct | **[llarp::rpc::DNSQUERY::request_parameters](Classes/structllarp_1_1rpc_1_1DNSQUERY_1_1request__parameters.md)**  |
| struct | **[llarp::rpc::CONFIG](Classes/structllarp_1_1rpc_1_1CONFIG.md)**  |
| struct | **[llarp::rpc::CONFIG::request_parameters](Classes/structllarp_1_1rpc_1_1CONFIG_1_1request__parameters.md)**  |




## Source code

```cpp
#pragma once

#include "json_binary_proxy.hpp"
#include "rpc_command_decorators.hpp"
#include <string_view>
#include <llarp/rpc/endpoints.hpp>
#include <llarp/config/config.hpp>
#include <oxenmq/oxenmq.h>
#include <oxenmq/address.h>
#include <oxen/log/omq_logger.hpp>



namespace llarp::rpc
{
  //  RPC: logs
  //    Creates or terminates log subscription via connection ID
  //
  struct LOGS : PUBLIC, IMMEDIATE
  {
    static constexpr auto names() { return NAMES("logs"); }
    // Note: ask jason about parameters to pass here
  };

  //  RPC: halt
  //    Stops lokinet router
  //
  //  Inputs: none
  //
  struct HALT : PUBLIC, NO_ARGS, IMMEDIATE
  {
    static constexpr auto name() { return NAMES("halt"); }
  };

  //  RPC: version
  //    Returns version and uptime information
  //
  //  Inputs: none
  //
  struct VERSION : PUBLIC, NO_ARGS, IMMEDIATE
  {
    static constexpr auto name() { return NAMES("version"); }
  };

  //  RPC: status
  //    Returns that current activity status of lokinet router
  //    Calls router::extractstatus
  //    
  //  Inputs: none
  //
  //  Returns:
  //    "running"
  //    "numNodesKnown"
  //    "dht"
  //    "services"
  //    "exit"
  //    "links"
  //    "outboundMessages"
  //
  struct STATUS : PUBLIC, NO_ARGS, DEFERRED
  {
    static constexpr auto name() { return NAMES("status"); }
  };

  //  RPC: get_status
  //    Returns current summary status
  //
  //  Inputs: none
  //
  //  Note: ask Jason
  //
  struct GETSTATUS : PUBLIC, NO_ARGS, DEFERRED
  {
    static constexpr auto name() { return NAMES("get_status", "getstatus"); }
  };

  //  RPC: quic_connect
  //    Initializes QUIC connection tunnel
  //    Passes request parameters in nlohmann::json format
  //
  //  Inputs:
  //    "endpoint" : endpoint id (string)
  //    "bind" : bind address (string, ex: "127.0.0.1:1142")
  //    "host" : remote host ID (string)
  //    "port" : port to bind to (int)
  //    "close" : close connection to port or host ID
  //
  //  Returns:
  //    "id" : connection ID
  //    "addr" : connection local address
  //    
  struct QUICCONNECT : PUBLIC, DEFERRED
  {
    static constexpr auto name() { return NAMES("quic_connect", "quicconnect"); }

    struct request_parameters
    {
      std::string endpoint;
      std::string bindAddr;
      std::string remoteHost;
      uint16_t port;
      int closeID;
    } request;
  };

  //  RPC: quick_listener
  //    Connects to QUIC interface on local endpoint
  //    Passes request parameters in nlohmann::json format
  //
  //  Inputs:
  //    "endpoint" : endpoint id (string)
  //    "host" : remote host ID (string)
  //    "port" : port to bind to (int)
  //    "close" : close connection to port or host ID
  //    "srv-proto" : 
  //    
  //  Returns:
  //    "id" : connection ID
  //    "addr" : connection local address
  //    
  struct QUICLISTENER : PUBLIC, DEFERRED
  {
    static constexpr auto name() { return NAMES("quic_listener", "quiclistener"); }

    struct request_parameters
    {
      std::string endpoint;
      std::string remoteHost;
      uint16_t port;
      int closeID;
      std::string srvProto;
    } request;
  };

  //  RPC: lookup_snode
  //    Look up service node
  //    Passes request parameters in nlohmann::json format
  //
  //  Inputs:
  //    "snode" : router ID to query (string)
  //    
  //  Returns:
  //    "ip" : snode IP address
  //    
  struct LOOKUPSNODE : PUBLIC, DEFERRED
  {
    static constexpr auto name() { return NAMES("lookup_snode", "lookupsnode"); }

    struct request_parameters
    {
      std::string routerID;
    } request;
  };

  //  RPC: endpoint
  //    Seems like this removes endpoints? which makes me think it should be protected
  //    
  //  Note: ask Jason
  //
  //  Inputs:
  //    "endpoint" : endpoint ID to query (string)
  //
  //  Returns:
  //    
  struct ENDPOINT : PROTECTED, DEFERRED
  {
    static constexpr auto name() { return NAMES("endpoint"); }

    struct request_parameters
    {
      std::string endpoint;
    } request;
  };

  //  RPC: exit
  //    Seems like this adds an exit node? which makes me think it should be protected
  //    
  //  Note: ask Jason about the internals of this
  //  
  //  Inputs:
  //    ""
  //
  //  Returns:
  //    
  struct EXIT : PROTECTED, DEFERRED
  {
    static constexpr auto name() { return NAMES("exit"); }

    struct request_parameters
    {
      std::string exitID;
    } request;
  };

  //  RPC: dns_query
  //    Attempts to query endpoint by domain name
  //
  //  Note: ask Jason about the internals of this
  //  
  //  Inputs:
  //    "endpoint" : endpoint ID to query (string)
  //    "qname" : query name (string)
  //    "qtype" : query type (int)
  //
  //  Returns:
  //    
  struct DNSQUERY : PROTECTED, IMMEDIATE
  {
    static constexpr auto name() { return NAMES("dns_query", "dnsquery"); }

    struct request_parameters
    {
      std::string endpoint;
      std::string qname;
      uint16_t qtype;
    } request;
  };

  //  RPC: config
  //    Runs lokinet router using .ini config file passed as path
  //
  //  Inputs: 
  //    "override" : path to config.ini file with which to override current config
  //    "reload" : restart router using current config file
  //    
  //  Returns:
  //    
  struct CONFIG : PROTECTED, IMMEDIATE
  {
    static constexpr auto name() { return NAMES("config"); }

    struct request_parameters
    {
      std::string override;
    } request;
  };


}  // namespace llarp::rpc
```


-------------------------------

Updated on 2023-01-13 at 17:17:16 +0000
